@@ -40,7 +40,7 @@ pub fn model(
     #[cfg(not(feature = "barrel-sqlite"))]
     let impl_barrel_sqlite = quote! {};
     #[cfg(feature = "barrel-sqlite")]
-    let impl_barrel_sqlite = barrel_impl::sqlite::impl_sqlite();
+    let impl_barrel_sqlite = barrel_impl::sqlite::impl_sqlite(&ast);
 
     // MYSQL
     #[cfg(not(feature = "mysql"))]
@@ -51,16 +51,22 @@ pub fn model(
     #[cfg(not(feature = "barrel-mysql"))]
     let impl_barrel_mysql = quote! {};
     #[cfg(feature = "barrel-mysql")]
-    let impl_barrel_mysql = barrel_impl::mysql::impl_mysql();
+    let impl_barrel_mysql = barrel_impl::mysql::impl_mysql(&ast);
 
     let output = quote! {
-        use schema::*;
+        use self::schema::*;
         #[cfg(any(feature = "sqlite", feature = "mysql"))]
         use {
-            ::diesel::{backend::Backend, prelude::*},
+            ::naphtha::diesel::{backend::Backend, prelude::*},
         };
 
-        #[derive(Debug, Queryable, Identifiable, AsChangeset, Associations)]
+        #[derive(
+            Debug,
+            Queryable,
+            Identifiable,
+            AsChangeset,
+            Associations
+            )]
         #attr
         #ast
 
